import java.awt.Image;
import java.awt.*;
import java.awt.event.*;
import java.lang.reflect.Method;
import java.awt.Image;
/**
 * Contains an image and can process a raw image.
 */
public class ImageContainer {
  private ImgProcStrategy currentStrategy= new DefaultStrategy();
  private Image aImage;
  /**
   * Embedded demo window class.
   */
  public class DemoFrame extends Frame
  {
    Label statusBar = new Label();
    Panel mainPanel = new Panel();
    ImageContainer parent;
    /**
     * Constructs a DemoFrame and starts the demo.
     * @param parent The demo object.
     */
    public DemoFrame(ImageContainer parent)
    {
      this.parent = parent;
      enableEvents(AWTEvent.WINDOW_EVENT_MASK);
      try
      {
        init();
      }
      catch(Exception e)
      {
        e.printStackTrace();
      }
    } //DemoFrame
    /**
     * GUI init.
     */
    private void init() throws Exception
    {
      this.setLayout(new BorderLayout());
      this.setSize(new Dimension(320, 240));
      this.setTitle("ImageContainer");
      statusBar.setText("Ready");
      this.add(mainPanel, BorderLayout.CENTER);
      this.add(statusBar, BorderLayout.SOUTH);
    } //init
    /**
     * Runs the demo.
     */
    public void runDemo() throws Exception
    {
      statusBar.setText("Created " + parent);
      byte[] rawImage = new byte[320*240*3];
      Object[] args = new Object[1];
      try
      {
        Class[] params = new Class[1];
        params[0] = rawImage.getClass();
        Method processRawImage = parent.getClass().getMethod("processRawImage", params);
        statusBar.setText("Method processRawImage(byte[]) found");
        args[0] = rawImage;
        Image image = (Image) processRawImage.invoke(parent, args);
        Graphics g = mainPanel.getGraphics();
        g.drawImage(image, 0, 0, mainPanel);
        g.dispose();
      }
      catch (NoSuchMethodException e)
      {
        statusBar.setText("Method processRawImage(byte[]) not found");
      }
    } //runDemo
    /**
     * Overridden event processing to link close event to button.
     * @param e The window event.
     */
    protected void processWindowEvent(WindowEvent e)
    {
      super.processWindowEvent(e);
      if(e.getID() == WindowEvent.WINDOW_CLOSING)
      {
        System.exit(0);
      }
    } //processWindowEvent
  } //class DemoFrame
  /**
   * Constructs an ImageContainer and starts the demo.
   */
  public ImageContainer()
  {
    try
    {
      DemoFrame frame = new DemoFrame(this);
      frame.validate();
      frame.setVisible(true);
      frame.runDemo();
    }
    catch(Exception e)
    {
      System.out.println(e.getMessage());
      e.printStackTrace();
    }
  } //ImageContainer
  /**
   * Main method.
   * @param args Application arguments array.
   */
  public static void main(String[] args)
  {
    ImageContainer img = new ImageContainer();
  } //main
  /**
   * Processes a raw image. Delegates to one strategy.
   */
  public Image processRawImage(byte[] rawImage) {
    try
    {
      return currentStrategy.processRawImage(rawImage);
    }
    catch (NoClassDefFoundError e)
    { //switch to other strategy
      switchStrategy();
      return currentStrategy.processRawImage(rawImage);
    }
  }
  /**
   * Switches between strategies
   */
  public void switchStrategy() {
    if (currentStrategy instanceof DefaultStrategy)
      currentStrategy = new CanvasStrategy();
    else
      currentStrategy = new DefaultStrategy();
  }
}