/**
 * Alarm data class for SEESCOA.
  AlarmData stores a date/time in a precision of milliseconds, a
  camera ID and a description.
 @author Miro Casanova
 @author Dennis Wagelaar
 @version 15 October 2002
 */
public class AlarmData extends TimeData {
  private ID cameraID= null;
  private String description= null;
  /**
   * Constructs an AlarmData.
   * @author Miro Casanova
   * @author Dennis Wagelaar
   */
  public AlarmData() {
    super();
  } //AlarmData
  /**
   * Constructs an AlarmData.
   * @param time The time data
   * @param camid The component ID
   * @param descr The alarm description
   * @author Dennis Wagelaar
   */
  public AlarmData(TimeData time, ID camid, String descr) {
    super(time);
    this.setCameraID(camid);
    this.setDescription(descr);
  } //AlarmData
  /**
   * Constructs an AlarmData.
   * @param year The year (e.g. 2002)
   * @param month The month (e.g. 12)
   * @param day The day of the month (e.g. 31)
   * @param hour The hour (e.g. 23)
   * @param minute The minute (e.g. 59)
   * @param second The second (e.g. 59)
   * @param msecond The amount of milliseconds (e.g. 999)
   * @param camid The component ID
   * @param descr The alarm description
   * @author Miro Casanova
   * @author Dennis Wagelaar
   */
  public AlarmData(int year, int month, int day, int hour, int minute, int second, int msecond, ID camid, String descr) {
    super(year, month, day, hour, minute, second, msecond);
    this.setCameraID(camid);
    this.setDescription(descr);
  } //AlarmData
  /**
   * Sets the property value
   */
  public void setDescription(String description) {
    this.description = description;
  }
  /**
   * Gets the property value
   */
  public String getDescription() {
    return this.description;
  }
  /**
   * Sets the property value
   */
  public void setCameraID(ID cameraID) {
    this.cameraID = cameraID;
  }
  /**
   * Gets the property value
   */
  public ID getCameraID() {
    return this.cameraID;
  }
  /**
   * Generates an ID from the CameraID
   */
  public ID getID() {
    return new ID(this.getCameraID().getIDstring() + "-" + this.getTimestamp() + "-" + this.getMilliSec());
  }
}