import java.awt.Image;
import java.awt.Image;
import java.awt.image.BufferedImage;
import java.awt.Image;
import java.awt.image.BufferedImage;
/**
 * Concrete strategy class.
 */
public class DefaultImageCreationStrategy implements ImageCreationStrategy {
  /**
   * Concrete Image creation algorithm.
   */
  public Image createImage(RawImage fromImage) {
    if (fromImage.getRgb())
      return createRGBImage(fromImage);
    else
      return createBWImage(fromImage);
  }
  /**
   * Creates an RGB Image from raw data.
   */
  private Image createRGBImage(RawImage fromImage) {
    int r, g, b;
    int width = fromImage.getWidth();
    int height = fromImage.getHeight();
    byte[] data = fromImage.getImageData();
    int[] pixels = new int[width * height];
    BufferedImage bi = new BufferedImage(width, height, BufferedImage.TYPE_INT_RGB);
    // create 32 bit integer array of rgb pixels
    for (int i = 0; i < width * height; i++) {
      r = data[i * 3];
      g = data[i * 3 + 1];
      b = data[i * 3 + 2];
      r &= 0xFF;
      g &= 0xFF;
      b &= 0xFF;
      pixels[i] = (255 << 24) | (r << 16) | (g << 8) | b;
    }
    // draw onto buffered image and return
    bi.setRGB(0, 0, width, height, pixels, 0, width);
    return bi;
  }
  /**
   * Creates a B&W Image from raw data.
   */
  private Image createBWImage(RawImage fromImage) {
    int pixel;
    int width = fromImage.getWidth();
    int height = fromImage.getHeight();
    byte[] data = fromImage.getImageData();
    int[] pixels = new int[width * height];
    BufferedImage bi = new BufferedImage(width, height, BufferedImage.TYPE_INT_RGB);
    // create 32 bit integer array of rgb pixels (r=g=b)
    for (int i = 0; i < width * height; i++) {
      pixel = data[i];
      pixel &= 0xFF;
      pixels[i] = (255 << 24) | (pixel << 16) | (pixel << 8) | pixel;
    }
    // draw onto buffered image and return
    bi.setRGB(0, 0, width, height, pixels, 0, width);
    return bi;
  }
}