import javax.swing.ImageIcon;
import java.awt.Image;
import java.awt.Image;
import javax.swing.ImageIcon;
import java.awt.Image;
/**
 * Video image class returned by the StorageController.
  This class contains all data on a video image stored in the
  database. It stores a date/time in a precision of milliseconds,
  a camera ID and an image.
 @author Miro Casanova
 @author Dennis Wagelaar
 @author Peter Rigole
 @version 28 October 2002
 */
public class StorageVideoImage extends TimeData {
  private ImageIcon internalImage= null;
  private DefaultImageCreationStrategy imageCreation= new DefaultImageCreationStrategy();;
  private RawImage fromImage= null;
  private ID cameraID= null;
  /**
   * Constructs a StorageVideoImage.
   * @author Miro Casanova
   */
  public StorageVideoImage() {
    super();
  } //StorageVideoImage
  /**
   * Constructs a StorageVideoImage.
   * @param time The time data for the image
   * @param camid The camera ID
   * @param image The image data
   * @author Dennis Wagelaar
   */
  public StorageVideoImage(TimeData time, ID camid, Image image) {
    super(time);
    this.setCameraID(camid);
    this.setImage(image);
  } //StorageVideoImage
  /**
   * Constructs a StorageVideoImage.
   * @param year The year (e.g. 2002)
   * @param month The month (e.g. 12)
   * @param day The day of the month (e.g. 31)
   * @param hour The hour (e.g. 23)
   * @param minute The minute (e.g. 59)
   * @param second The second (e.g. 59)
   * @param msecond The amount of milliseconds (e.g. 999)
   * @param camid The camera ID
   * @param image The image data
   * @author Dennis Wagelaar
   */
  public StorageVideoImage(int year, int month, int day, int hour, int minute, int second, int msecond, ID camid, Image image) {
    super(year, month, day, hour, minute, second, msecond);
    this.setCameraID(camid);
    this.setImage(image);
  } //StorageVideoImage
  /**
   * Gets the property value
   */
  public ID getCameraID() {
    return this.cameraID;
  }
  /**
   * Sets the property value
   */
  public void setCameraID(ID cameraID) {
    this.cameraID = cameraID;
  }
  /**
   * Generates an ID from the CameraID
   */
  public ID getID() {
    return new ID(this.getCameraID().getIDstring() + "-" + this.getTimestamp() + "-" + this.getMilliSec());
  }
  /**
   * 
   */
  public void setImage(Image imageVar) {
    this.internalImage = new ImageIcon(imageVar);
  }
  /**
   * Sets a raw image.
   */
  public void setRawImage(RawImage fromImage) {
    // postpone Image creation and save preliminary image data
    this.fromImage = fromImage;
    internalImage = null;
  }
  /**
   * 
   */
  public Image getImage() {
    // create from raw image if applicable
    if ((internalImage == null) && (fromImage != null))
          this.setImage( imageCreation.createImage(fromImage) );
    // return image
    return internalImage.getImage();
  }
}